@@ -47,6 +47,8 @@
  * https://voikko.sourceforge.net/
  */
 
+static EnchantProvider *provider;
+
 static int
 voikko_dict_check (EnchantDict * me, const char *const word, size_t len)
 {
@@ -145,7 +147,7 @@ voikko_provider_request_dict (EnchantProvider * me, const char *const tag)
 		return NULL;
 	}
 
-	EnchantDict *dict = enchant_dict_new ();
+	EnchantDict *dict = enchant_dict_new (provider, tag);
 	if (dict == NULL)
 		return NULL;
 	dict->user_data = (void *)voikko_handle;
@@ -167,14 +169,21 @@ voikko_provider_describe (EnchantProvider * me _GL_UNUSED)
 	return "Voikko Provider";
 }
 
+static void
+voikko_provider_dispose (EnchantProvider * me _GL_UNUSED)
+{
+	provider = NULL;
+}
+
 EnchantProvider *init_enchant_provider (void);
 
 EnchantProvider *
 init_enchant_provider (void)
 {
-	EnchantProvider *provider = enchant_provider_new ();
+	provider = enchant_provider_new ();
 	if (provider == NULL)
 		return NULL;
+	provider->dispose = voikko_provider_dispose;
 	provider->request_dict = voikko_provider_request_dict;
 	provider->dispose_dict = voikko_provider_dispose_dict;
 	provider->dictionary_exists = voikko_provider_dictionary_exists;
